@@ -14,7 +14,7 @@ from fastapi import FastAPI
 from hypy_utils import ensure_dir, write, json_stringify, printc, color
 from ruamel import yaml
 
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 config_path = ensure_dir(Path.home() / '.config' / 'mc-auth')
 access_token_path = config_path / 'data' / 'access_token.json'
 
@@ -63,7 +63,7 @@ def get_login_code() -> str:
         'scope': 'XboxLive.signin offline_access',
         'state': 'NOT_NEEDED'
     })
-    printc(f'&6Opening {url} in the browser...')
+    print(f'Opening {url} in the browser...')
     if webbrowser.open(url):
         printc(f'&6If the link does not open, please open it manually.')
     else:
@@ -174,8 +174,11 @@ def get_mc_token(xsts_token: str, user_hash: str) -> str:
     write(out_path, json_stringify(r, indent=2))
     printc(f'&a> Success! Response saved to {out_path}')
 
+    mc_uuid = config_path / 'mc-uuid.txt'
     mc_token = config_path / 'mc-token.txt'
+    write(mc_uuid, r['username'])
     write(mc_token, r['access_token'])
+    printc(f'&a> Minecraft UUID saved to {mc_uuid}')
     printc(f'&a> Minecraft token saved to {mc_token}')
 
     return r['access_token']
